/*
 * Show Q
 * Copyright (c) 2007-2008 Errol van de l'Isle
 *
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *      MA 02110-1301, USA.
 */

#include "editcue.h"
#include "app.h"
#include "main.h"

// Stop cue editing

EditCueStop::EditCueStop(Gtk::Notebook *)
{
}

EditCueStop::~EditCueStop()
{
}

void EditCueStop::set(std::shared_ptr<Cue> &)
{
}

void EditCueStop::get(std::shared_ptr<Cue> &)
{
}

// Pause cue editing

EditCuePause::EditCuePause(Gtk::Notebook *)
{
}

EditCuePause::~EditCuePause()
{
}

void EditCuePause::set(std::shared_ptr<Cue> &)
{
}

void EditCuePause::get(std::shared_ptr<Cue> &)
{
}

// Start cue editing

EditCueStart::EditCueStart(Gtk::Notebook *)
{
}

EditCueStart::~EditCueStart()
{
}

void EditCueStart::set(std::shared_ptr<Cue> &)
{
}

void EditCueStart::get(std::shared_ptr<Cue> &)
{
}
